==> kie-wb-common-7.0.0.Final-project-sources.tar.gz: kie-wb-common-7.0.0.Final/kie-wb-common-screens/kie-wb-common-workbench/kie-wb-common-workbench-client/src/main/java/org/kie/workbench/common/workbench/client/PerspectiveIds.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.workbench.client;

public interface PerspectiveIds {

    String HOME = "HomePerspective";
    String SOCIAL_HOME = "SocialHomePagePerspective";
    String SOCIAL_USER_HOME = "UserHomePagePerspective";
    String SECURITY_MANAGEMENT = "SecurityManagementPerspective";
    String AUTHORING = "AuthoringPerspective";
    String CONTRIBUTORS = "ContributorsPerspective";
    String GUVNOR_M2REPO = "GuvnorM2RepoPerspective";
    String ADMINISTRATION = "AdministrationPerspective";
    String LIBRARY = "LibraryPerspective";
    String DROOLS_ADMIN = "DroolsAdminPerspective";
    String PLANNER_ADMIN = "PlannerAdminPerspective";
    String PROCESS_DEFINITIONS = "ProcessDefinitions";
    String PROCESS_INSTANCES = "ProcessInstances";
    String PLUGIN_AUTHORING = "PlugInAuthoringPerspective";
    String APPS = "AppsPerspective";
    String DATASET_AUTHORING = "DataSetAuthoringPerspective";
    String DEPLOYMENTS = "Deployments";
    String SERVER_MANAGEMENT = "ServerManagementPerspective";
    String JOBS = "Requests";
    String TASKS = "Tasks";
    String PROCESS_DASHBOARD = "DashboardPerspective";
    String BUSINESS_DASHBOARDS = "ContentManagerPerspective";
    String DATASOURCE_MANAGEMENT = "DataSourceManagementPerspective";
    String ADMIN = "AdminPagePerspective";
}

==> kie-wb-common-7.6.0.Final-project-sources.tar.gz: kie-wb-common-7.6.0.Final/kie-wb-common-screens/kie-wb-common-workbench/kie-wb-common-workbench-client/src/main/java/org/kie/workbench/common/workbench/client/PerspectiveIds.java <==
/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.workbench.client;

public interface PerspectiveIds {

    String HOME = "HomePerspective";
    String SOCIAL_HOME = "SocialHomePagePerspective";
    String SOCIAL_USER_HOME = "UserHomePagePerspective";
    String SECURITY_MANAGEMENT = "SecurityManagementPerspective";
    String AUTHORING = "AuthoringPerspective";
    String GUVNOR_M2REPO = "GuvnorM2RepoPerspective";
    String ADMINISTRATION = "AdministrationPerspective";
    String LIBRARY = "LibraryPerspective";
    String DROOLS_ADMIN = "DroolsAdminPerspective";
    String PLANNER_ADMIN = "PlannerAdminPerspective";
    String PROCESS_DEFINITIONS = "ProcessDefinitions";
    String PROCESS_INSTANCES = "ProcessInstances";
    String PLUGIN_AUTHORING = "PlugInAuthoringPerspective";
    String APPS = "AppsPerspective";
    String DATASET_AUTHORING = "DataSetAuthoringPerspective";
    String DEPLOYMENTS = "ProvisioningManagementPerspective";
    String SERVER_MANAGEMENT = "ServerManagementPerspective";
    String JOBS = "Requests";
    String EXECUTION_ERRORS = "ExecutionErrors";
    String TASKS = "Tasks";
    String TASKS_ADMIN = "TaskAdmin";
    String PROCESS_DASHBOARD = "DashboardPerspective";
    String CONTENT_MANAGEMENT = "ContentManagerPerspective";
    String DATASOURCE_MANAGEMENT = "DataSourceManagementPerspective";
    String ADMIN = "AdminPagePerspective";
}
